/**
 * @file
 */


/**
 * Processing module javascript file to switch between render & source.
 *
 * We can't generate script elements on the fly because in Webkit,
 * Gecko, and IE it will always try to compile the script in JavaScript
 * even when type is NOT text/javascript. This doesn't make any sense.
 *
 * A note on performance. There can be a maximum of 0..n processing
 * instances loaded on a page where n is the number of [processing] tag
 * blocks on the page. This value is always increasing and never
 * decreasing so it is possible for a user to overload themselves for
 * high values of n.
 */
if (Drupal.jsEnabled) {
  $(document).ready(function () {
    var instances = new Array;

    $(".processing-wrapper").each(function() {
      if ($(this).children(".processing-button").length == 0 || $(this).children(".processing-button").attr('value') == Drupal.t('View Source')) {
        var canvas = $(this).children('canvas');
        var script = $(this).children('script');
        var canvas_element = script.next('canvas').get(0);
        canvas.show(400);

        if (instances[canvas.attr('id')] === undefined) {
          try {
            instances[canvas.attr('id')] = new Processing(canvas_element, script.get(0).text);
          }
          catch (err) {
            if ($(this).siblings('div.messages').length == 0) {
              $(this).before('<div class="messages error">' + Drupal.t('Syntax Error: ') + err.message + '</div>');
            }
          }
        }
      }
    });

    $(".processing-button").click(function() {
      if ($(this).attr('value') == Drupal.t('Render Sketch')) {
        $(this).attr('value', Drupal.t('View Source'));
        var pre = $(this).nextAll('pre');
        var canvas = $(this).nextAll('canvas');
        var script = $(this).nextAll('script');
        var canvas_element = script.next('canvas').get(0);
        pre.hide(400);
        canvas.show(400);
        
        // If by any chance the process is still running, let's
        // NOT start a new one.
        if (instances[canvas.attr('id')] === undefined) {
          try {
            instances[canvas.attr('id')] = new Processing(canvas_element, script.get(0).text);
          }
          catch (err) {
            $(this).attr('value', Drupal.t('Render Sketch'));
            pre.show(400);
            canvas.hide(400);
//            console.log($(this).prev('div.messages'));
            if ($(this).siblings('div.messages').length == 0) {
              $(this).before('<div class="messages error">' + Drupal.t('Syntax Error: ') + err.message + '</div>');
            }
          }
        }
      }
      else {
        $(this).attr('value', Drupal.t('Render Sketch'));
        $(this).nextAll('pre').show(400);
        $(this).nextAll('canvas').hide(400);
        // @todo We're out of context here so delete or Processing.removeInstances
        // won't work. Since it doesn't work, we still want to keep it in the
        // instances array in case the user clicks the button again.
        // delete instances[$(this).nextAll('canvas').attr('id')];
      }
    });
  });
}
